-- -----------------------------------------------------------------------------
--
--   _____      _            _
--  / ____|    | |          (_)        
-- | |     ___ | | ___  _ __ _ _______ 
-- | |    / _ \| |/ _ \| '__| |_  / _ \
-- | |___| (_) | | (_) | |  | |/ /  __/
--  \_____\___/|_|\___/|_|  |_/___\___|
--    
-- Making your startup colorful!
--  
-- Author: "Remen"
--                               
-- -----------------------------------------------------------------------------

-- Declarations

	-- this is who/what we are!
	declare('Colorize', Colorize or {})

-- Revision information, notes, variables, and header data

	-- current release information: "major . minor . bug fix"
	Colorize.version = "1.1.0"

	-- start off paused
	Colorize.paused=false

-- Main routines to colorize names based on faction, pause and unpause based on game state

	-- Here be colorization
	function Colorize.FixNames()

		-- sanity check to ensure we have data loaded before we start trying to manipulate it
		if not GetCharacterInfo(1) then
			-- we haven't finished loading, so let's try again in .5 second
			Timer ():SetTimeout (500, function ()
				Colorize.FixNames() 
			end)
			return
		end

		-- the elements aren't named, so we have to refer to them by [n] references
		local elem = CharSelectDialog[1][1][1][2][1][1][1]

		-- only 6 slots, so let's scan all of them
		for i=1,6,1 do
			elem=iup.GetBrother(elem) -- omg, can't even get this reference directly?! OK, find. Let's get a brother.
			local my_button=elem[1][1] -- this is the the button that holds the play name
			local my_label=elem[1][2][1] -- this is the label that shows your faction, and location.
			local guild=""
					
			local name, faction, _, _, _, _, _, _, _, _, _, _ = GetCharacterInfo(i) -- my_label.title
			-- faction=string.match(faction,"(%a+) - ") -- we only care about your faction, so let's slice it off

			local color="128 128 128" -- default dark gray
			local bright_color="255 255 255" -- default bright gray (white)

			if faction=="Itani" then -- blue
				color="25 25 128" 
				bright_color="50 50 255"
			end

			if faction=="Serco" then -- red
				color="128 25 25"
				bright_color="255 50 50"
			end

			if faction=="UIT" then -- yellow
				color="128 128 25"
				bright_color="255 255 50"
			end

			if my_label.fgcolor=="255 255 255" then -- if the button was selected, the label will turn bright white
				my_button.fgcolor=bright_color -- if the label is bright white, let's use the bright color
			else
				my_button.fgcolor=color -- otherwise, we use the dark color
			end

			if (name) then
				guild="[" .. gkini.ReadString("Colorize", name, "") .. "] "
				if (guild~="[] ") then 
					my_button.title = guild .. name 
				end
			end

		end

		-- ok, the game resets the colors every click. sooooo... we have to come back every now and then and reset it
		-- back to our preferred colors. (blue, red, and yellow (and sometimes gray))
		Timer ():SetTimeout (100, function ()
			Colorize.FixNames() 
		end)

	end

	-- pause colorization, duh.
	function Colorize.Pause()
		Colorize.paused=true
		-- we're logged in, let's get our guild name and player name and stick them in the config file for use when we aren't logged in
		if (GetGuildAcronym()) then
			gkini.WriteString("Colorize", GetPlayerName(), GetGuildAcronym())
		end
	end

	-- unpause colorization, double duh.
	function Colorize.Unpause()
		Colorize.paused=false
		Colorize.FixNames()
	end

-- Let's hook the events that let us do work.
	RegisterEvent(Colorize.Unpause, "LOGIN_SUCCESSFUL")
	RegisterEvent(Colorize.Unpause, "PLAYER_LOGGED_OUT")
	RegisterEvent(Colorize.Pause, "UPDATE_CHARINFO")
